"use strict";

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _rimraf = _interopRequireDefault(require("rimraf"));

var _utils = require("../utils");

var _paths = _interopRequireDefault(require("../paths"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const unnecessaryArgumentsCount = 2;
const args = process.argv.slice(unnecessaryArgumentsCount);
const isWatching = process.env.SCRIPT_WATCH === 'true';
const useBuiltinConfig = !args.includes('--presets') && !(0, _utils.hasFile)('.babelrc') && !(0, _utils.hasPkgProp)('babel');
const config = useBuiltinConfig ? ['--presets', require.resolve('gd-configs/babel')] : [];
const ignore = args.includes('--ignore') ? [] : ['--ignore', '**/*.test.js,**/*.test.ts,**/*.test.tsx,**/*.d.ts,__mocks__,@types'];
const copyFiles = args.includes('--no-copy-files') ? [] : ['--copy-files'];
const useSpecifiedOutDir = args.includes('--out-dir');
const outDir = useSpecifiedOutDir ? [] : ['--out-dir', _paths.default.output];
const extensions = ['--extensions', '.ts,.tsx,.js'];
const sourceMaps = isWatching ? [] : ['-s'];
const watch = isWatching ? ['-w'] : [];

if (!isWatching) {
  (0, _utils.logScriptMessage)('BUILD');
}

if (!useSpecifiedOutDir && !args.includes('--no-clean')) {
  _rimraf.default.sync(_paths.default.output); // eslint-disable-next-line no-console


  console.log('Cleaned the build dir.');
}

const babelArguments = [...outDir, ...copyFiles, ...ignore, ...config, ...extensions, 'src', ...sourceMaps, ...watch, ...args];

const resultBabel = _crossSpawn.default.sync((0, _utils.resolveBin)('@babel/cli', {
  executable: 'babel'
}), babelArguments, {
  stdio: 'inherit'
});

let resultTypescript;

if ((0, _utils.isTypescript)() && !isWatching) {
  resultTypescript = _crossSpawn.default.sync((0, _utils.resolveBin)('typescript', {
    executable: 'tsc'
  }), ['--emitDeclarationOnly'], {
    stdio: 'inherit'
  });
  console.log('Typescript declarations emitted.');
} // Exclude ignored files from the dist dir


if (ignore.length > 0 && !isWatching) {
  const buildIgnore = ignore[1].split(',').filter(x => x !== '**/*.d.ts') // Do not exclude type definitions
  .map(x => `dist/${x}`).join(',');

  _rimraf.default.sync(`{${buildIgnore}}`);
}

const getResult = (ts, babel) => {
  if (ts !== undefined) {
    return Math.max(ts.status, babel.status);
  }

  return babel.status;
};

const result = getResult(resultTypescript, resultBabel);
process.exit(result);
//# sourceMappingURL=build.js.map