"use strict";

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _yargsParser = _interopRequireDefault(require("yargs-parser"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const unnecessaryArgumentsCount = 2;
let args = process.argv.slice(unnecessaryArgumentsCount);
const parsedArgs = (0, _yargsParser.default)(args);
const useBuiltinConfig = !args.includes('--config') && !(0, _utils.hasFile)('.eslintrc') && !(0, _utils.hasFile)('.eslintrc.js') && !(0, _utils.hasPkgProp)('eslintConfig');
const useBuiltinIgnore = !args.includes('--ignore-path') && !(0, _utils.hasFile)('.eslintignore') && !(0, _utils.hasPkgProp)('eslintIgnore');
const ignore = useBuiltinIgnore ? ['--ignore-path', require.resolve('gd-configs/eslint/ignore')] : [];
const config = useBuiltinConfig ? ['--config', require.resolve((0, _utils.getEslintConfigPath)())] : [];
const cache = args.includes('--no-cache') ? [] : ['--cache'];
const filesGiven = parsedArgs._.length > 0;
const filesToApply = filesGiven ? [] : ['.'];
const extensions = ['--ext', '.js,.ts,.tsx'];
const cacheLocation = ['--cache-location', 'node_modules/.cache/.eslintcache'];

const isLintable = file => file.endsWith('.js') || file.endsWith('.ts') || file.endsWith('.tsx');

const isCi = !!process.env.SCRIPT_CI;
const maxWarnings = isCi ? ['--max-warnings=0'] : [];

if (filesGiven) {
  // we need to take all the flag-less arguments (the files that should be linted)
  // and filter out the ones that aren't js files. Otherwise json or css files
  // may be passed through
  args = args.filter(a => !parsedArgs._.includes(a) || isLintable(a));
}

const lintArguments = [...config, ...ignore, ...maxWarnings, ...extensions, ...cacheLocation, ...cache, ...args, ...filesToApply];
(0, _utils.logScriptMessage)('LINT');

const result = _crossSpawn.default.sync((0, _utils.resolveBin)('eslint'), lintArguments, {
  stdio: 'inherit'
});

process.exit(result.status);
//# sourceMappingURL=lint.js.map